Introduction to Fire Dynamics
=============================

Introductory fire dynamics calculations and concepts.

.. automodule:: ofire.introduction_to_fire_dynamics
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 6 - Ignition Processes
-------------------------------

.. automodule:: ofire.introduction_to_fire_dynamics.chapter_6_intro
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 6.32 - Time to Ignition for Thermally Thick Materials
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.introduction_to_fire_dynamics.chapter_6_intro.equation_6_32
   :members:
   :undoc-members:
   :show-inheritance:

Equation 6.33 - Time to Ignition for Thermally Thin Materials
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.introduction_to_fire_dynamics.chapter_6_intro.equation_6_33
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 10 - Compartment Fire Dynamics
---------------------------------------

.. automodule:: ofire.introduction_to_fire_dynamics.chapter_10_intro
   :members:
   :undoc-members:
   :show-inheritance:

Equation Modules
~~~~~~~~~~~~~~~~

Equation 10.18 - Ventilation Parameter and Burning Regime
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. automodule:: ofire.introduction_to_fire_dynamics.chapter_10_intro.equation_10_18
   :members:
   :undoc-members:
   :show-inheritance: